"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HasGenerators = exports.UpdateGenerators = exports.GetGenerators = exports.ProjectRootOrNameOrConfigurationToProjectRoot = exports.GetGeneratorFile = exports.ExistsGeneratorFile = exports.GetGeneratorFilePath = exports.HasGeneratorProperty = void 0;
const workspace_utilities_1 = require("@rxap/workspace-utilities");
const path_1 = require("path");
function HasGeneratorProperty(packageJson) {
    return !!packageJson['generators'] || !!packageJson['schematics'];
}
exports.HasGeneratorProperty = HasGeneratorProperty;
function GetGeneratorFilePath(projectRoot, packageJson) {
    var _a;
    if (!packageJson['generators'] && !packageJson['schematics']) {
        throw new Error(`The package.json of the project ${projectRoot} does not contains a generators property!`);
    }
    return (0, path_1.join)(projectRoot, (_a = packageJson['generators']) !== null && _a !== void 0 ? _a : packageJson['schematics']);
}
exports.GetGeneratorFilePath = GetGeneratorFilePath;
function ExistsGeneratorFile(tree, projectRoot, packageJson) {
    return tree.exists(GetGeneratorFilePath(projectRoot, packageJson));
}
exports.ExistsGeneratorFile = ExistsGeneratorFile;
function GetGeneratorFile(tree, projectRoot, packageJson) {
    var _a;
    const generatorFile = GetGeneratorFilePath(projectRoot, packageJson);
    const content = (_a = tree.read(generatorFile)) === null || _a === void 0 ? void 0 : _a.toString('utf-8');
    if (!content) {
        throw new Error(`The generator file ${generatorFile} does not exists!`);
    }
    try {
        return JSON.parse(content);
    }
    catch (e) {
        throw new Error(`The generator file ${generatorFile} is not valid json!: ${e.message}`);
    }
}
exports.GetGeneratorFile = GetGeneratorFile;
function ProjectRootOrNameOrConfigurationToProjectRoot(tree, projectRootOrNameOrConfiguration) {
    if (typeof projectRootOrNameOrConfiguration === 'string') {
        if (projectRootOrNameOrConfiguration.match(/^\/?([^/]+\/)+[^/]+/)) {
            return projectRootOrNameOrConfiguration;
        }
        else {
            const project = (0, workspace_utilities_1.GetProject)(tree, projectRootOrNameOrConfiguration);
            if (project) {
                return project.root;
            }
            else {
                throw new Error(`The project ${projectRootOrNameOrConfiguration} does not exists!`);
            }
        }
    }
    else {
        return projectRootOrNameOrConfiguration.root;
    }
}
exports.ProjectRootOrNameOrConfigurationToProjectRoot = ProjectRootOrNameOrConfigurationToProjectRoot;
function GetGenerators(tree, projectRootOrNameOrConfiguration) {
    const projectRoot = ProjectRootOrNameOrConfigurationToProjectRoot(tree, projectRootOrNameOrConfiguration);
    const packageJson = (0, workspace_utilities_1.GetPackageJson)(tree, projectRoot);
    if (!HasGeneratorProperty(packageJson)) {
        throw new Error(`The project ${projectRoot} does not contains a generators property!`);
    }
    if (!ExistsGeneratorFile(tree, projectRoot, packageJson)) {
        throw new Error(`The generator file ${GetGeneratorFilePath(projectRoot, packageJson)} does not exists!`);
    }
    return GetGeneratorFile(tree, projectRoot, packageJson);
}
exports.GetGenerators = GetGenerators;
function UpdateGenerators(tree, projectRootOrNameOrConfiguration, update) {
    const projectRoot = ProjectRootOrNameOrConfigurationToProjectRoot(tree, projectRootOrNameOrConfiguration);
    const packageJson = (0, workspace_utilities_1.GetPackageJson)(tree, projectRoot);
    if (!HasGeneratorProperty(packageJson)) {
        throw new Error(`The project ${projectRoot} does not contains a generators property!`);
    }
    if (!ExistsGeneratorFile(tree, projectRoot, packageJson)) {
        throw new Error(`The generator file ${GetGeneratorFilePath(projectRoot, packageJson)} does not exists!`);
    }
    const generators = GetGeneratorFile(tree, projectRoot, packageJson);
    tree.write(GetGeneratorFilePath(projectRoot, packageJson), JSON.stringify(update(generators), null, 2) + '\n');
}
exports.UpdateGenerators = UpdateGenerators;
function HasGenerators(tree, projectRootOrNameOrConfiguration) {
    const projectRoot = ProjectRootOrNameOrConfigurationToProjectRoot(tree, projectRootOrNameOrConfiguration);
    const packageJson = (0, workspace_utilities_1.GetPackageJson)(tree, projectRoot);
    if (!HasGeneratorProperty(packageJson)) {
        return false;
    }
    if (!ExistsGeneratorFile(tree, projectRoot, packageJson)) {
        return false;
    }
    const generators = GetGeneratorFile(tree, projectRoot, packageJson);
    if (!Object.keys(generators.generators).length) {
        return false;
    }
    return true;
}
exports.HasGenerators = HasGenerators;
//# sourceMappingURL=generators.js.map