"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GetAllPackageDependenciesForProject = void 0;
const get_direct_package_dependencies_for_project_1 = require("./get-direct-package-dependencies-for-project");
const project_package_name_mapping_1 = require("./project-package-name-mapping");
/**
 * Get the all package dependencies for the project.
 *
 * All package dependencies are the dependent projects that are directly and indirect referenced by the project.
 * This includes the dependencies of the dependent projects.
 *
 * @param context
 * @param projectName
 */
function GetAllPackageDependenciesForProject(context, projectName = context.projectName, resolvedDependencies = {}) {
    const { projectGraph } = context;
    if (!projectGraph) {
        throw new Error('The projectGraph is undefined. Ensure the projectGraph is passed into the executor context.');
    }
    if (!projectName) {
        throw new Error('The projectName is undefined. Ensure the projectName is passed into the executor context.');
    }
    const directDependencies = (0, get_direct_package_dependencies_for_project_1.getDirectPackageDependenciesForProject)(context, projectName);
    const allDependencies = Object.assign({}, directDependencies);
    for (const packageName of Object.keys(directDependencies)) {
        if (resolvedDependencies[packageName]) {
            continue;
        }
        const project = (0, project_package_name_mapping_1.PackageNameToProjectName)(packageName);
        const dependencies = GetAllPackageDependenciesForProject(context, project, directDependencies);
        Object.assign(allDependencies, dependencies);
    }
    return allDependencies;
}
exports.GetAllPackageDependenciesForProject = GetAllPackageDependenciesForProject;
//# sourceMappingURL=get-all-package-dependencies-for-project.js.map