"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HasProjectWithPackageName = exports.ProjectNameToPackageName = exports.PackageNameToProjectName = exports.LoadProjectToPackageMapping = void 0;
const fs_1 = require("fs");
const PACKAGE_NAME_TO_PROJECT_NAME_CACHE = {};
const PROJECT_NAME_TO_PACKAGE_NAME_CACHE = {};
function LoadProjectToPackageMapping(context) {
    const { projectGraph } = context;
    if (!projectGraph) {
        throw new Error('The projectGraph is undefined. Ensure the projectGraph is passed into the executor context.');
    }
    const projectNames = Object.keys(projectGraph.nodes);
    for (const projectName of projectNames) {
        const project = projectGraph.nodes[projectName];
        if (project.type !== 'lib') {
            continue;
        }
        const projectRoot = project.data.root;
        if (!(0, fs_1.existsSync)(`${projectRoot}/package.json`)) {
            continue;
        }
        const packageJSON = JSON.parse((0, fs_1.readFileSync)(`${projectRoot}/package.json`).toString('utf-8'));
        PACKAGE_NAME_TO_PROJECT_NAME_CACHE[packageJSON.name] = projectName;
        PROJECT_NAME_TO_PACKAGE_NAME_CACHE[projectName] = packageJSON.name;
    }
}
exports.LoadProjectToPackageMapping = LoadProjectToPackageMapping;
function PackageNameToProjectName(packageName) {
    if (!PACKAGE_NAME_TO_PROJECT_NAME_CACHE) {
        throw new Error('The project to package name cache has not been loaded yet.');
    }
    if (PACKAGE_NAME_TO_PROJECT_NAME_CACHE[packageName]) {
        return PACKAGE_NAME_TO_PROJECT_NAME_CACHE[packageName];
    }
    throw new Error(`Could not find project for package '${packageName}'`);
}
exports.PackageNameToProjectName = PackageNameToProjectName;
function ProjectNameToPackageName(projectName) {
    if (!PROJECT_NAME_TO_PACKAGE_NAME_CACHE) {
        throw new Error('The project to package name cache has not been loaded yet.');
    }
    if (PROJECT_NAME_TO_PACKAGE_NAME_CACHE[projectName]) {
        return PROJECT_NAME_TO_PACKAGE_NAME_CACHE[projectName];
    }
    throw new Error(`Could not find package for project '${projectName}'`);
}
exports.ProjectNameToPackageName = ProjectNameToPackageName;
function HasProjectWithPackageName(packageName) {
    if (!PACKAGE_NAME_TO_PROJECT_NAME_CACHE) {
        throw new Error('The project to package name cache has not been loaded yet.');
    }
    return PACKAGE_NAME_TO_PROJECT_NAME_CACHE[packageName] !== undefined;
}
exports.HasProjectWithPackageName = HasProjectWithPackageName;
//# sourceMappingURL=project-package-name-mapping.js.map